param($installPath, $toolsPath, $package, $project)

Import-Module (Join-Path $toolsPath common.psm1) -Force

try {

    # Indicates if current project is a VB project
    $IsVbProject = ($project.CodeModel.Language -eq [EnvDTE.CodeModelLanguageConstants]::vsCMLanguageVB)
    
    if ($IsVbProject) {

        # Remove added Imports for VB project
        $VbImports | ForEach-Object {
            if ($project.Object.Imports -contains $_) {
                $project.Object.Imports.Remove($_)
            }
        }
    }
    
    # Remove references
    Foreach ($spRef in $ReferencesToRemoveWhenUninstall) {
        $project.Object.References | Where-Object { $_.Name -eq $spRef } | ForEach-Object { $_.Remove() }
    }
    
} catch {

    Write-Host "Error uninstalling package: " + $_.Exception -ForegroundColor Red
    exit
}
# SIG # Begin signature block
# MIIhgwYJKoZIhvcNAQcCoIIhdDCCIXACAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDlvZuuC+GMoftG
# w75jWywFY00XrPgyHeqxmwIpoxRxU6CCCzAwggS4MIIDoKADAgECAhMzAAAAFhEE
# tIg4jL7DAAAAAAAWMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTAwHhcNMTIwODMwMTc0OTAzWhcNMTMxMTMwMTc0OTAzWjCBgzEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjENMAsGA1UECxMETU9Q
# UjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMIIBIjANBgkqhkiG9w0B
# AQEFAAOCAQ8AMIIBCgKCAQEAoFCfHU6UugcK3L6WSeE9oAbvlb75vVYqW5zvHhEu
# xtbhLbJvzDMtnh6ksYIWymQxqYomgfTjLvIeDhzI4Vnh1CM9ZXf/6uW3s40I9hLX
# b0lXpIXjBB7QQqinstswChXRyTVtf7yGXqU+tpBkBSQcPqBxaAox937Ulektm8pl
# BXoUAgwJ9rPdcV0mH1oLLwm6ZzJsnBXYnDyJ6Ec676YU30I+IR67MeIs0VT26oCS
# K5M0d22SZyY2wSox23gTSauTldxsqgwAccDNzd1j7ZFXl6+MKoTF3g11ZYzg0R9B
# O7u1ktJpOXWYAExsTD0YQwPOZjucXU5ReJFCO37QWuBfQwIDAQABo4IBJzCCASMw
# HwYDVR0lBBgwFgYIKwYBBQUHAwMGCisGAQQBgjc9BgEwHQYDVR0OBBYEFGvZ8Xb4
# o3g0pPdGnifxsLlszzamMB8GA1UdIwQYMBaAFOb8X3u7IgBY5HJOtfQhdCMy5u+s
# MFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kv
# Y3JsL3Byb2R1Y3RzL01pY0NvZFNpZ1BDQV8yMDEwLTA3LTA2LmNybDBaBggrBgEF
# BQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
# a2kvY2VydHMvTWljQ29kU2lnUENBXzIwMTAtMDctMDYuY3J0MAwGA1UdEwEB/wQC
# MAAwDQYJKoZIhvcNAQELBQADggEBAFJC8724+Xy7MrKL26QtkBCpQrdInr35S1zM
# IWCkvYCXYy4qifab1rwikgFznoP78otrvTBa7O0wPu7I4X+oNyn3TB+t3iPXKm0l
# CtEwPkPxqrVFOKtuROPQoQMz11o05SExK44oLnjtZXIHh7X+vBbErC9ky6LNyeoH
# anVi68zmZqk8wTI5xdHAbGv6BTwrbbP7R/26vByAXRKG1Cva0iwoMn1XBYQngR/w
# QWVSAfBqr3kNuO3AY6dE1vmeAlVFDnheXNsAeullJHMSeLZQ+TYmSJQE7dhA1eE9
# QzcfmEWdLOM22nMwVJdqHiBcE/kO2Iwwtus+dYSl62OSCi1JS7YwggZwMIIEWKAD
# AgECAgphDFJMAAAAAAADMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJVUzET
# MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
# TWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9vdCBD
# ZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0xMDA3MDYyMDQwMTdaFw0yNTA3
# MDYyMDUwMTdaMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# KDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTAwggEiMA0G
# CSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDpDmRQeWe1xOP9CQBMnpSs91Zo6kTY
# z8VYT6mldnxtRbrTOZK0pB75+WWC5BfSj/1EnAjoZZPOLFWEv30I4y4rqEErGLei
# S25JTGsVB97R0sKJHnGUzbV/S7SvCNjMiNZrF5Q6k84mP+zm/jSYV9UdXUn2siou
# 1YW7WT/4kLQrg3TKK7M7RuPwRknBF2ZUyRy9HcRVYldy+Ge5JSA03l2mpZVeqyiA
# zdWynuUDtWPTshTIwciKJgpZfwfs/w7tgBI1TBKmvlJb9aba4IsLSHfWhUfVELnG
# 6Krui2otBVxgxrQqW5wjHF9F4xoUHm83yxkzgGqJTaNqZmN4k9Uwz5UfAgMBAAGj
# ggHjMIIB3zAQBgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQU5vxfe7siAFjkck61
# 9CF0IzLm76wwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGG
# MA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186a
# GMQwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
# aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsG
# AQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwgZ0GA1UdIASB
# lTCBkjCBjwYJKwYBBAGCNy4DMIGBMD0GCCsGAQUFBwIBFjFodHRwOi8vd3d3Lm1p
# Y3Jvc29mdC5jb20vUEtJL2RvY3MvQ1BTL2RlZmF1bHQuaHRtMEAGCCsGAQUFBwIC
# MDQeMiAdAEwAZQBnAGEAbABfAFAAbwBsAGkAYwB5AF8AUwB0AGEAdABlAG0AZQBu
# AHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQAadO9XTyl7xBaFeLhQ0yL8CZ2sgpf4
# NP8qLJeVEuXkv8+/k8jjNKnbgbjcHgC+0jVvr+V/eZV35QLU8evYzU4eG2Giwloj
# GvCMqGJRRWcI4z88HpP4MIUXyDlAptcOsyEp5aWhaYwik8x0mOehR0PyU6zADzBp
# f/7SJSBtb2HT3wfV2XIALGmGdj1R26Y5SMk3YW0H3VMZy6fWYcK/4oOrD+Brm5XW
# fShRsIlKUaSabMi3H0oaDmmp19zBftFJcKq2rbtyR2MX+qbWoqaG7KgQRJtjtrJp
# iQbHRoZ6GD/oxR0h1Xv5AiMtxUHLvx1MyBbvsZx//CJLSYpuFeOmf3Zb0VN5kYWd
# 1dLbPXM18zyuVLJSR2rAqhOV0o4R2plnXjKM+zeF0dx1hZyHxlpXhcK/3Q2PjJst
# 67TuzyfTtV5p+qQWBAGnJGdzz01Ptt4FVpd69+lSTfR3BU+FxtgL8Y7tQgnRDXbj
# I1Z4IiY2vsqxjG6qHeSF2kczYo+kyZEzX3EeQK+YZcki6EIhJYocLWDZN4lBiSoW
# D9dhPJRoYFLv1keZoIBA7hWBdz6c4FMYGlAdOJWbHmYzEyc5F3iHNs5Ow1+y9T1H
# U7bg5dsLYT0q15IszjdaPkBCMaQfEAjCVpy/JF1RAp1qedIX09rBlI4HeyVxRKsG
# aubUxt8jmpZ1xTGCFakwghWlAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQI
# EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
# ZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcg
# UENBIDIwMTACEzMAAAAWEQS0iDiMvsMAAAAAABYwDQYJYIZIAWUDBAIBBQCggbIw
# GQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisG
# AQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIOW4wAOiCP/bqD7/Bc/FcgsljBvcn2fW
# f84QR9EivzbxMEYGCisGAQQBgjcCAQwxODA2oByAGgB1AG4AaQBuAHMAdABhAGwA
# bAAuAHAAcwAxoRaAFGh0dHA6Ly9taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEBAQUA
# BIIBABfLi2DN2Cb3NdgMy0UMdC8rjs8y3LfmB+xE+KRXNcqZMrEzMM+UAI0aJBUp
# NbEgQgh2xGbtCkkdoi1cvChYfO3xcB/ubQfsCnoKiixrXtaWoBIMQGItjjm1fB+t
# iqdVrotrACqVYgspe4xoZLS827/RCFJYpZBNciL8s1ojAJPrCdttW0uqNQ8iNgau
# GlC5VCQlAm+9qYgNM9WQlH5dG433iWkkFufYNMLve5wdyWu/BjDAi1NgmlEwNjii
# pi3oNK1CFyJ3nFSrDr365hS7toy+NwhEdvqpgImC6/jN+o0O9gQP4Df6VENhoDbm
# U0fxnAsBKLDTOayyl1litbNzjlehghMvMIITKwYKKwYBBAGCNwMDATGCExswghMX
# BgkqhkiG9w0BBwKgghMIMIITBAIBAzEPMA0GCWCGSAFlAwQCAQUAMIIBPQYLKoZI
# hvcNAQkQAQSgggEsBIIBKDCCASQCAQEGCisGAQQBhFkKAwEwMTANBglghkgBZQME
# AgEFAAQgRPRZ0FqpnLUGQ8ChQlJGXGvViXBZ5U0hIMdEEfpa5fUCBlEBP0MP/hgT
# MjAxMzAyMjYwMzU2NTkuMjEzWjAHAgEBgAIB9KCBuaSBtjCBszELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjENMAsGA1UECxMETU9QUjEnMCUGA1UE
# CxMebkNpcGhlciBEU0UgRVNOOjMxQzUtMzBCQS03QzkxMSUwIwYDVQQDExxNaWNy
# b3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIOxDCCBnEwggRZoAMCAQICCmEJgSoA
# AAAAAAIwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
# YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
# Q29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRl
# IEF1dGhvcml0eSAyMDEwMB4XDTEwMDcwMTIxMzY1NVoXDTI1MDcwMTIxNDY1NVow
# fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
# TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggEiMA0GCSqGSIb3DQEBAQUA
# A4IBDwAwggEKAoIBAQCpHQ28dxGKOiDs/BOX9fp/aZRrdFQQ1aUKAIKF++18aEss
# X8XD5WHCdrc+Zitb8BVTJwQxH0EbGpUdzgkTjnxhMFmxMEQP8WCIhFRDDNdNuDgI
# s0Ldk6zWczBXJoKjRQ3Q6vVHgc2/JGAyWGBG8lhHhjKEHnRhZ5FfgVSxz5NMksHE
# pl3RYRNuKMYa+YaAu99h/EbBJx0kZxJyGiGKr0tkiVBisV39dx898Fd1rL2KQk1A
# UdEPnAY+Z3/1ZsADlkR+79BL/W7lmsqxqPJ6Kgox8NpOBpG2iAg16HgcsOmZzTzn
# L0S6p/TcZL2kAcEgCZN4zfy8wMlEXV4WnAEFTyJNAgMBAAGjggHmMIIB4jAQBgkr
# BgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQU1WM6XIoxkPNDe3xGG8UzaFqFbVUwGQYJ
# KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
# MAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQwVgYDVR0fBE8w
# TTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVj
# dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEBBE4wTDBK
# BggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9N
# aWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwgaAGA1UdIAEB/wSBlTCBkjCBjwYJ
# KwYBBAGCNy4DMIGBMD0GCCsGAQUFBwIBFjFodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vUEtJL2RvY3MvQ1BTL2RlZmF1bHQuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwA
# ZQBnAGEAbABfAFAAbwBsAGkAYwB5AF8AUwB0AGEAdABlAG0AZQBuAHQALiAdMA0G
# CSqGSIb3DQEBCwUAA4ICAQAH5ohRDeLG4Jg/gXEDPZ2joSFvs+umzPUxvs8F4qn+
# +ldtGTCzwsVmyWrf9efweL3HqJ4l4/m87WtUVwgrUYJEEvu5U4zM9GASinbMQEBB
# m9xcF/9c+V4XNZgkVkt070IQyK+/f8Z/8jd9Wj8c8pl5SpFSAK84Dxf1L3mBZdmp
# tWvkx872ynoAb0swRCQiPM/tA6WWj1kpvLb9BOFwnzJKJ/1Vry/+tuWOM7tiX5rb
# V0Dp8c6ZZpCM/2pif93FSguRJuI57BlKcWOdeyFtw5yjojz6f32WapB4pm3S4Zz5
# Hfw42JT0xqUKloakvZ4argRCg7i1gJsiOCC1JeVk7Pf0v35jWSUPei45V3aicaoG
# ig+JFrphpxHLmtgOR5qAxdDNp9DvfYPw4TtxCd9ddJgiCGHasFAeb73x4QDf5zEH
# pJM692VHeOj4qEir995yfmFrb3epgcunCaw5u+zGy9iCtHLNHfS4hQEegPsbiSpU
# ObJb2sgNVZl6h3M7COaYLeqN4DMuEin1wC9UJyH3yKxO2ii4sanblrKnQqLJzxlB
# TeCG+SqaoxFmMNO7dDJL32N79ZmKLxvHIa9Zta7cRDyXUHHXodLFVeNp3lfB0d4w
# wP3M5k37Db9dT+mdHhk4L7zPWAUu7w2gUDXa7wknHNWzfjUeCLraNtvTX4/edIhJ
# EjCCBNEwggO5oAMCAQICCmEH3W0AAAAAAA8wDQYJKoZIhvcNAQELBQAwfDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
# b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcNMTIwMTA5MjEzNTM0WhcNMTMwNDA5
# MjE0NTM0WjCBszELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEN
# MAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNOOjMxQzUtMzBC
# QS03QzkxMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIIB
# IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2GZvTO+m/ipRKQ7dAw92j4jf
# tYlPOC/bGcoUtWl35Tu1CmxhPkn1tILBKkjdx7QWDQk58608mURcqYkUW5k0iSf/
# 8I1aOtJHsi+A38eg5sJrfiKsv8UwBqDYOQctR93AdRl1Dq1FipIbfKpSpwTIWM74
# MNhWdn5fM7A5UJetCy8ys8F0f5tPcJajIxQXFTyHK8Adz2aITkaIXCb5RxyBfCRX
# DboYxas/tb30fdXs+Rp69Qo5bTcGA0SC1BkU40wUmZSVTnwGSZyNilNYInwJf2ua
# jR9bwmNWk8AoC4IhAISwa9udEugOAGzm9Rw8Q6AyhGbyo9KDobUXajISmsXhHwID
# AQABo4IBGzCCARcwHQYDVR0OBBYEFEXFckm8eVZosNLbzYvjrnJ6YvyMMB8GA1Ud
# IwQYMBaAFNVjOlyKMZDzQ3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeGRWh0
# dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1RpbVN0
# YVBDQV8yMDEwLTA3LTAxLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
# Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljVGltU3RhUENB
# XzIwMTAtMDctMDEuY3J0MAwGA1UdEwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYBBQUH
# AwgwDQYJKoZIhvcNAQELBQADggEBABfJ8eSSXUtHkzZ1IpLs85Bs/N4naQ8NcPmc
# zpElgsCilD9yMgXiQ0YR/6eb7KnCe3mkB8h5tOylQTK0sVj8mBUTUEZmuhXc2/Kx
# D1gxV+dKNrKXN1dxz1e8yqFPDhpq4UD05y3ZXzGYmdw1qslfgh07dsQEqzyr1Tgx
# 5pmHRBibzuCw3GjuOjylRMRxtGEuuPC6dP4E2gt87cX8XrZj0vBorf7uqVDeCJo1
# ZRnamg4un3EGb5divl+2qULTKT3Vev2QS6WL8U1kxUh4cc1wosMAP9P8aBimoK7N
# 4QPdL2kPhd0w5/SS+prHFjg0T6H/HSqjHfmb/NSfz0pM/jqt3xShggN2MIICXgIB
# ATCB46GBuaSBtjCBszELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjENMAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNOOjMxQzUt
# MzBCQS03QzkxMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNl
# oiUKAQEwCQYFKw4DAhoFAAMVAHXEwXwCUhjGN7y5u4XRbLBxRSEaoIHCMIG/pIG8
# MIG5MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
# UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQL
# EwRNT1BSMScwJQYDVQQLEx5uQ2lwaGVyIE5UUyBFU046QjAyNy1DNkY4LTFEODgx
# KzApBgNVBAMTIk1pY3Jvc29mdCBUaW1lIFNvdXJjZSBNYXN0ZXIgQ2xvY2swDQYJ
# KoZIhvcNAQEFBQACBQDU1n9dMCIYDzIwMTMwMjI2MDAyNTAxWhgPMjAxMzAyMjcw
# MDI1MDFaMHQwOgYKKwYBBAGEWQoEATEsMCowCgIFANTWf10CAQAwBwIBAAICAQsw
# BwIBAAICF4owCgIFANTX0N0CAQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGE
# WQoDAaAKMAgCAQACAxbjYKEKMAgCAQACAwehIDANBgkqhkiG9w0BAQUFAAOCAQEA
# qmscdFrFYSWef00kvqz+aXQUWHQnUsb0vzF0fWCSV/hcMrbJs8hz9zs9BC1Wf2K1
# 0r1+sBmm18Ixig+3+0ukFLa/d41qnF0lXVWQqCQzCgVvisn6g97viqImRRSPDqI1
# Keyp2Lk4ujnpJXIM/k7N3l+669+/ia66T4GroCxhaM6JOivlBo4VFP35iGLOrFZ9
# 96oOOtz46EMeMSZpgfVtBYJ8ZrSdNOo/+ZtPqCS0aOfMJ0isfgY8SEzxjnnlMbhO
# ubwiiv1dNyU50flD+b4HPTDJg/fvi+noBD95g2tQO/ZOQjWVBHTwDMOOYMAgpt3j
# XvUGBEY+FYKqhSacbZurBDGCAuMwggLfAgEBMIGKMHwxCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0
# YW1wIFBDQSAyMDEwAgphB91tAAAAAAAPMA0GCWCGSAFlAwQCAQUAoIIBKTAaBgkq
# hkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIEIKJMEGKDD6TP
# qch+hJ4Y+iiBqkTbtebSBzw+e1RI1KonMIHZBgsqhkiG9w0BCRACDDGByTCBxjCB
# wzCBqAQUdcTBfAJSGMY3vLm7hdFssHFFIRowgY8wgYCkfjB8MQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
# ZS1TdGFtcCBQQ0EgMjAxMAIKYQfdbQAAAAAADzAWBBScHTOFqx35wjL32JAmrgEn
# tGa/AjANBgkqhkiG9w0BAQsFAASCAQBX225ajyo7Kb5CwaBNYMJ+PZSpJ1wvrurG
# 9ZE1dkdahNhfkoxvPcvg8cmDHqphG1NJv6zgNaRz3gZ0AhHfTU+BKEKunjtZZu1g
# NsJ1oDSSiUasoIvfB5bANKCTqn1ech/jh8r5HD41ublPk+MfZKu4ApUE5plgHFfi
# xKybVNulVHLPEPGa1eRVOa57lA7KZiBZr30vSoSChaPrOcYMAR0+2KmZZu0/Z5Z4
# L2/j1zWe8hAcDL55SRICRBgGBJydeAptTV6ZVVi42kzYVFwvzvSLINnvP0GA+LC/
# pN7c2WoscKbeg6O00WjlZygSlIp2ybQeg3lrOZ/unEsNIUZBUPj9
# SIG # End signature block
