﻿"use strict"
window.WingtipToys = window.WingtipToys || {};
WingtipToys.Jsom = WingtipToys.Jsom || {};
WingtipToys.Rest = WingtipToys.Rest || {};

$(document).ready(function () {
    
    $("#mainDiv").hide();
    $("#loadingDiv").show();

    /***************/
    /* App Loading */
    /***************/

    //Create 2 announcement lists with 2 items each
    $.when(

        //One from REST
        WingtipToys.Rest.Lists.create(
            "REST Announcements",
            "The REST Announcements List",
            SP.ListTemplateType.announcements),

        //The other from JSOM
        WingtipToys.Jsom.Lists.create(
            "JSOM Announcements",
            "The JSOM Announcements List",
            SP.ListTemplateType.announcements)

     ).done(

            function (x1, x2) {

                var titleRest = x1[0].d.Title;
                var typeRest = x1[0].d.ListItemEntityTypeFullName;
                var titleJsom = x2.get_title();

                $.when(

                    //Create a list items in each list
                    WingtipToys.Rest.ListItems.create(titleRest, typeRest, "Announcement1"),
                    WingtipToys.Jsom.ListItems.create(titleJsom, "Announcement1")

                ).done(
 
                    function (x1, x2) {

                        //Load the ViewModels
                        WingtipToys.ViewModel.Rest.load(titleRest);
                        WingtipToys.ViewModel.Jsom.load(titleJsom);

                        //Apply Knockout Bindings
                        ko.applyBindings(WingtipToys.ViewModel.Rest, document.getElementById("restTable"));
                        ko.applyBindings(WingtipToys.ViewModel.Jsom, document.getElementById("jsomTable"));

                        //Show UI
                        $("#mainDiv").show();
                        $("#loadingDiv").hide();

                    });
            });


    /****************/
    /* Click Events */
    /****************/


    //Create a new item in each list
    $("#newItemButton").click(function () {

        var newItemTitle = $("#inputText").attr("value");

        $.when(

            //Create a list items in each list
            WingtipToys.Rest.ListItems.create(
            "REST Announcements",
            "SP.Data.REST_x0020_AnnouncementsListItem",
            newItemTitle),

            WingtipToys.Jsom.ListItems.create(
            "JSOM Announcements",
            newItemTitle))

       .done(

        function (x1, x2) {

            //Load the ViewModels
            WingtipToys.ViewModel.Rest.load("REST Announcements");
            WingtipToys.ViewModel.Jsom.load("JSOM Announcements");

        });
    });

    //Create a new field in each list
    $("#newFieldButton").click(function () {

        var newDisplayName = $("#inputText").attr("value");

        //JSOM requires the type of the field as a string
        WingtipToys.Jsom.Fields.add_field("JSOM Announcements", newDisplayName, "Text")
            .then(
            function (newField) {
                alert("Created field '" + newField.get_title() + "'");
            },
            function (sender, args) {
                alert(args.get_message());
            }
        );

        //REST requires an SP.FieldType Enumeration
        WingtipToys.Rest.Fields.add_field("REST Announcements", newDisplayName, 2)
           .then(
           function (data) {
               alert("Created field '" + data.d.Title + "'");
           },
           function (err) {
               alert(JSON.stringify(err));
           }
       );
    });

    //Create a new site column in web
    $("#newSiteColumnButton").click(function () {

        var newDisplayName = $("#inputText").attr("value");

        //JSOM requires the type of the field as a string
        WingtipToys.Jsom.Fields.add_siteColumn(newDisplayName + "_jsom", "Choice", true)
            .then(
            function (newField) {
                WingtipToys.Jsom.Fields.add_siteColumnChoice(newField.get_title(), "Choice1", true)
                .then(
                function (choiceField) {
                    alert("Created site Column '" + choiceField.get_title() + "'");
                },
                function (sender, args) {
                    alert(args.get_message());
                }
                );
            },
            function (sender, args) {
                alert(args.get_message());
            }
        );

        //REST requires an SP.FieldType Enumeration
        WingtipToys.Rest.Fields.add_siteColumn(newDisplayName + "_rest", SP.FieldType.choice, false)
           .then(
           function (data) {
               var schema = data.d.SchemaXml.replace("<CHOICES />","<CHOICES><CHOICE>Choice1</CHOICE></CHOICES>"); 
               WingtipToys.Rest.Fields.add_siteColumnChoice(data.d.Title, schema, false)
               .then(
               function (data) {
                   alert("Created site Column '" + newDisplayName + "_rest" + "'");
               },
               function (err) {
                   alert(JSON.stringify(err));
               }
               );
           },
           function (err) {
               alert(JSON.stringify(err));
           }
       );
    });

    //Create a new site content type in web
    $("#newSiteContentType").click(function () {

        var newDisplayName = $("#inputText").attr("value");

        WingtipToys.Jsom.Lists.create_contentType(newDisplayName + "_jsom", "A new content type", "0x0101", true)
        .then(
            function (newContentType) {
                var name = newContentType.get_name();
                alert("Created new Content Type '" + name + "'");
            },
            function (sender, args) {
                alert(args.get_message());
            }
        );

        WingtipToys.Rest.Lists.create_contentType(newDisplayName + "_rest", "A new content type", "0x0101", true)
        .then(
            function (data) {
                var name = data.d.Name;
                alert("Created new Content Type '" + name + "'");
            },
            function (err) {
                alert(JSON.stringify(err));
            }
        );


    });

    //Change the Title field display name
    $("#newDisplayNameButton").click(function () {

        var newFieldTitle = $("#inputText").attr("value");

        WingtipToys.Jsom.Fields.set_displayName("JSOM Announcements", "Title", newFieldTitle)
            .then(
            function (titleField) {
                alert("Update 'Title' display name to '" + titleField.get_title() + "'");
            },
            function (sender, args) {
                alert(args.get_message());
            }
        );

        WingtipToys.Rest.Fields.set_displayName("REST Announcements", "Title", newFieldTitle)
           .then(
           function () {
               alert("Update 'Title' display name to '" + newFieldTitle + "'");
           },
           function (err) {
               alert(JSON.stringify(err));
           }
       );

    });

    //Delete Both Lists
    $("#deleteListsButton").click(function () {
        $.when(
        WingtipToys.Rest.Lists.remove("REST Announcements"),
        WingtipToys.Jsom.Lists.remove("JSOM Announcements")).done(

            function (x1, x2) {
                alert("Lists are now deleted! You can safely leave the page.");
                $("#mainDiv").hide();
            }

        );
    });

});


/*****************/
/* App Unloading */
/*****************/

window.onbeforeunload = function () {
    if ($("#mainDiv").is(":visible")) {
        ; return "Don't leave without deleting the lists!";
    }
}


