﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.BusinessData;
using Microsoft.BusinessData.SystemSpecific;
using Microsoft.BusinessData.MetadataModel;
using Microsoft.BusinessData.MetadataModel.Collections;

namespace ProductConnector.ProductModel
{
    public partial class ProductService : IContextProperty
    {
        public IList<Product> ReadProducts()
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());

            var q = from p in catalog.Products
                    orderby p.Name
                    select p;

            List<Product> products = new List<Product>();

            foreach (var i in q)
            {
                products.Add(
                    new Product()
                    {
                        ProductID = i.ProductID,
                        CategoryID = i.CategoryID,
                        Name = i.Name,
                        Number = i.Number,
                        Color = i.Color,
                        Description = i.Description
                    });
            }

            return products;
        }

        public Product ReadProduct(int productID)
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());

            var q = from p in catalog.Products
                    where p.ProductID == productID
                    select p;

            if (q.Count() == 1)
            {
                return new Product()
                {
                    ProductID = q.First().ProductID,
                    CategoryID = q.First().CategoryID,
                    Name = q.First().Name,
                    Number = q.First().Number,
                    Color = q.First().Color,
                    Description = q.First().Description
                };
            }
            else
            {
                return null;
            }

        }


        public Product CreateProduct(Product newProduct)
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());
            ProductConnector.Product product = new ProductConnector.Product();

            product.CategoryID = newProduct.CategoryID;
            product.Name = newProduct.Name;
            product.Number = newProduct.Number;
            product.Color = newProduct.Color;
            product.Description = newProduct.Description;

            catalog.AddToProducts(product);
            catalog.SaveChanges();
            newProduct.ProductID = product.ProductID;
            return newProduct;
        }

        public void DeleteProduct(int productID)
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());
            ProductConnector.Product product = catalog.Products.First(p => p.ProductID == productID);
            catalog.DeleteObject(product);
            catalog.SaveChanges();
        }

        public void UpdateProduct(Product product)
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());
            ProductConnector.Product updatedProduct = catalog.Products.First(p => p.ProductID == product.ProductID);
            updatedProduct.CategoryID = product.CategoryID;
            updatedProduct.Name = product.Name;
            updatedProduct.Color = product.Color;
            updatedProduct.Description = product.Description;
            updatedProduct.Number = product.Number;
            catalog.SaveChanges();

        }


        public Stream ReadPhoto(int productID)
        {
            AdventureworksBCSCatalog catalog = new AdventureworksBCSCatalog(GetConnectionInfo());
            var q = from p in catalog.Products
                    where p.ProductID == productID
                    select p;

            if (q.Count() == 1)
            {
                byte[] buffer = q.First().Photo;
                return new MemoryStream(buffer);
            }
            else
            {
                return null;
            }
        }

        internal string GetConnectionInfo()
        {
            INamedPropertyDictionary props =
              this.LobSystemInstance.GetProperties();
            if (props.ContainsKey("AdventureworksCatalog"))
                return props["AdventureworksCatalog"].ToString();
            else
                return string.Empty;
        }
        public Microsoft.BusinessData.Runtime.IExecutionContext
               ExecutionContext
        {
            get;
            set;
        }
        public Microsoft.BusinessData.MetadataModel.ILobSystemInstance
               LobSystemInstance
        {
            get;
            set;
        }
        public Microsoft.BusinessData.MetadataModel.IMethodInstance
               MethodInstance
        {
            get;
            set;
        }

        public static IEnumerable<Category> ProductToCategory(int productID)
        {
            throw new System.NotImplementedException();
        }


    }
}
