﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.SharePoint;

namespace ExternalColumnSamples
{
    class Program
    {
        static void Main(string[] args)
        {
            /* http://dev.wingtip.com/bcs
             * contains a library called "Shared Documents"
             * with an External Column named "Company" */

            using (SPSite siteCollection = new SPSite("http://dev.wingtip.com/bcs"))
            {
                using (SPWeb site = siteCollection.OpenWeb())
                {
                    SPList list = site.Lists["Shared Documents"];

                    //CAML QUERY AGAINST LIST WITH EXTERNAL COLUMN
                    Console.WriteLine("CAML Query");
                    Console.WriteLine("**********");
                    SPQuery caml = new SPQuery();
                    //Notice the field is just queried as a regular text field because data is just copied into it
                    caml.Query = "<Where><Eq><FieldRef Name='Company'/><Value Type='Text'>Blue Yonder Airlines</Value></Eq></Where>";
                    caml.ViewFields = "<FieldRef Name='Title'/><FieldRef Name='Company'/>";
                    SPListItemCollection items = list.GetItems(caml);
                    int lastItemId = 0;
                    int itemCount = items.Count;
                    Console.WriteLine("Found " + itemCount + " item(s).");
                    foreach (SPListItem item in items)
                    {
                        Console.WriteLine(item["Title"]);
                        Console.WriteLine(item["Company"]);
                        lastItemId = item.ID;
                    }
                    items = null;

                    //UPDATE THE VALUE OF THE EXTERNAL COLUMN
                    if (itemCount > 0)
                    {
                        Console.WriteLine();
                        Console.WriteLine("Column Update");
                        Console.WriteLine("*************");
                        SPListItem lastItem = list.GetItemById(lastItemId);
                        SPBusinessDataField externalColumn = (SPBusinessDataField)lastItem.Fields["Company"];
                        externalColumn.ParseAndSetValue(lastItem, "Wingtip Toys");
                        lastItem.Update();
                    }
                }
            }
            Console.WriteLine();
            Console.WriteLine("Done");
            Console.Read();
        }
    }
}
